require "puppet/parameter/boolean"

# Autogenic core type

Puppet::Type.newtype(:azure_api_management_service_resource) do
  @doc = "A single API Management service resource in List or Get response."

  ensurable

  validate do
    required_properties = [
      :location,
      :properties,
      :sku,
      :parameters,
      :resource_group_name,
      :service_name,
    ]
    required_properties.each do |property|
      # We check for both places so as to cover the puppet resource path as well
      if self[:ensure] == :present && self[property].nil? && self.provider.send(property) == :absent
        raise Puppet::Error, "In azure_api_management_service_resource you must provide a value for #{property}"
      end
    end
  end
  newproperty(:etag) do
    desc "ETag of the resource."
    validate do |value|
      true
    end
  end
  newproperty(:id) do
    desc "Resource ID."
    validate do |value|
      true
    end
  end
  newproperty(:identity) do
    desc "Managed service identity of the Api Management service."
    validate do |value|
      true
    end
  end
  newproperty(:location) do
    desc "Resource location."
    validate do |value|
      true
    end
  end
  newparam(:name) do
    isnamevar
    desc "Resource name."
    validate do |value|
      true
    end
  end
  newproperty(:properties) do
    desc "Properties of the API Management service."
    validate do |value|
      true
    end
  end
  newproperty(:sku) do
    desc "SKU properties of the API Management service."
    validate do |value|
      true
    end
  end
  newproperty(:tags) do
    desc "Resource tags."
    validate do |value|
      true
    end
  end
  newproperty(:type) do
    desc "Resource type for API Management resource is set to Microsoft.ApiManagement."
    validate do |value|
      true
    end
  end
  newparam(:api_version) do
    desc "Version of the API to be used with the client request."
    validate do |value|
      true
    end
  end
  newparam(:parameters) do
    desc "Parameters supplied to the CreateOrUpdate API Management service operation."
    validate do |value|
      true
    end
  end
  newparam(:resource_group_name) do
    desc "The name of the resource group."
    validate do |value|
      true
    end
  end
  newparam(:service_name) do
    desc "The name of the API Management service."
    validate do |value|
      true
    end
  end
  newparam(:subscription_id) do
    desc "Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call."
    validate do |value|
      true
    end
  end
end
