require "puppet/parameter/boolean"

# Autogenic core type

Puppet::Type.newtype(:azure_storage_classification_mapping) do
  @doc = "Storage mapping object."

  ensurable

  validate do
    required_properties = []
    required_properties.each do |property|
      # We check for both places so as to cover the puppet resource path as well
      if self[:ensure] == :present && self[property].nil? && self.provider.send(property) == :absent
        raise Puppet::Error, "In azure_storage_classification_mapping you must provide a value for #{property}"
      end
    end
  end
  newproperty(:id) do
    desc "Resource Id"
    validate do |value|
      true
    end
  end
  newproperty(:location) do
    desc "Resource Location"
    validate do |value|
      true
    end
  end
  newparam(:name) do
    isnamevar
    desc "Resource Name"
    validate do |value|
      true
    end
  end
  newproperty(:properties) do
    desc "Properties of the storage mapping object."
    validate do |value|
      true
    end
  end
  newproperty(:type) do
    desc "Resource Type"
    validate do |value|
      true
    end
  end
  newparam(:api_version) do
    desc "Client Api Version."
    validate do |value|
      true
    end
  end
  newparam(:fabric_name) do
    desc "Fabric name."
    validate do |value|
      true
    end
  end
  newparam(:pairing_input) do
    desc "Pairing input."
    validate do |value|
      true
    end
  end
  newparam(:resource_group_name) do
    desc "The name of the resource group where the recovery services vault is present."
    validate do |value|
      true
    end
  end
  newparam(:resource_name) do
    desc "The name of the recovery services vault."
    validate do |value|
      true
    end
  end
  newparam(:storage_classification_name) do
    desc "Storage classification name."
    validate do |value|
      true
    end
  end
  newparam(:subscription_id) do
    desc "The subscription Id."
    validate do |value|
      true
    end
  end
end
