require "puppet/parameter/boolean"

# Autogenic core type

Puppet::Type.newtype(:azure_virtual_machine_scale_set_vm) do
  @doc = "Describes a virtual machine scale set virtual machine."

  ensurable

  validate do
    required_properties = [
      :location,
      :parameters,
      :resource_group_name,
      :virtual_machine_scale_set_name,
      :vm_scale_set_name,
    ]
    required_properties.each do |property|
      # We check for both places so as to cover the puppet resource path as well
      if self[:ensure] == :present && self[property].nil? && self.provider.send(property) == :absent
        raise Puppet::Error, "In azure_virtual_machine_scale_set_vm you must provide a value for #{property}"
      end
    end
  end
  newproperty(:id) do
    desc "Resource Id"
    validate do |value|
      true
    end
  end
  newproperty(:instance_id) do
    desc "The virtual machine instance ID."
    validate do |value|
      true
    end
  end
  newproperty(:location) do
    desc "Resource location"
    validate do |value|
      true
    end
  end
  newparam(:name) do
    isnamevar
    desc "Resource name"
    validate do |value|
      true
    end
  end
  newproperty(:plan) do
    desc "Specifies information about the marketplace image used to create the virtual machine. This element is only used for marketplace images. Before you can use a marketplace image from an API, you must enable the image for programmatic use.  In the Azure portal, find the marketplace image that you want to use and then click **Want to deploy programmatically, Get Started ->**. Enter any required information and then click **Save**."
    validate do |value|
      true
    end
  end
  newproperty(:properties) do
    desc ""
    validate do |value|
      true
    end
  end
  newproperty(:resources, :array_matching => :all) do
    desc "The virtual machine child extension resources."
    validate do |value|
      true
    end
  end
  newproperty(:sku) do
    desc "The virtual machine SKU."
    validate do |value|
      true
    end
  end
  newproperty(:tags) do
    desc "Resource tags"
    validate do |value|
      true
    end
  end
  newproperty(:type) do
    desc "Resource type"
    validate do |value|
      true
    end
  end
  newproperty(:zones, :array_matching => :all) do
    desc "The virtual machine zones."
    validate do |value|
      true
    end
  end
  newparam(:api_version) do
    desc "Client Api Version."
    validate do |value|
      true
    end
  end
  newparam(:parameters) do
    desc "Parameters supplied to the Update Virtual Machine Scale Sets VM operation."
    validate do |value|
      true
    end
  end
  newparam(:resource_group_name) do
    desc "The name of the resource group."
    validate do |value|
      true
    end
  end
  newparam(:subscription_id) do
    desc "Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call."
    validate do |value|
      true
    end
  end
  newparam(:vm_scale_set_name) do
    desc "The name of the VM scale set where the extension should be create or updated."
    validate do |value|
      true
    end
  end
end
